"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import api_pb2
import builtins
import collections.abc
import communities_pb2
import discussions_pb2
import events_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import requests_pb2
import sys
import threads_pb2
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _SVFailReason:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SVFailReasonEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SVFailReason.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SV_FAIL_REASON_UNKNOWN: _SVFailReason.ValueType  # 0
    SV_FAIL_REASON_WRONG_BIRTHDATE_OR_GENDER: _SVFailReason.ValueType  # 1
    """birthdate doesn't match profile or gender"""
    SV_FAIL_REASON_NOT_A_PASSPORT: _SVFailReason.ValueType  # 2
    """not a passport (e.g. used a ID card)"""
    SV_FAIL_REASON_DUPLICATE: _SVFailReason.ValueType  # 3
    """this passport is already used by someone else or the same user"""

class SVFailReason(_SVFailReason, metaclass=_SVFailReasonEnumTypeWrapper): ...

SV_FAIL_REASON_UNKNOWN: SVFailReason.ValueType  # 0
SV_FAIL_REASON_WRONG_BIRTHDATE_OR_GENDER: SVFailReason.ValueType  # 1
"""birthdate doesn't match profile or gender"""
SV_FAIL_REASON_NOT_A_PASSPORT: SVFailReason.ValueType  # 2
"""not a passport (e.g. used a ID card)"""
SV_FAIL_REASON_DUPLICATE: SVFailReason.ValueType  # 3
"""this passport is already used by someone else or the same user"""
Global___SVFailReason: typing_extensions.TypeAlias = SVFailReason

class _PostalVerificationFailReason:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PostalVerificationFailReasonEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PostalVerificationFailReason.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    POSTAL_VERIFICATION_FAIL_REASON_UNKNOWN: _PostalVerificationFailReason.ValueType  # 0
    POSTAL_VERIFICATION_FAIL_REASON_CODE_EXPIRED: _PostalVerificationFailReason.ValueType  # 1
    """Code expired (90 days since postcard sent)"""
    POSTAL_VERIFICATION_FAIL_REASON_TOO_MANY_ATTEMPTS: _PostalVerificationFailReason.ValueType  # 2
    """Too many wrong attempts (5 attempts)"""

class PostalVerificationFailReason(_PostalVerificationFailReason, metaclass=_PostalVerificationFailReasonEnumTypeWrapper): ...

POSTAL_VERIFICATION_FAIL_REASON_UNKNOWN: PostalVerificationFailReason.ValueType  # 0
POSTAL_VERIFICATION_FAIL_REASON_CODE_EXPIRED: PostalVerificationFailReason.ValueType  # 1
"""Code expired (90 days since postcard sent)"""
POSTAL_VERIFICATION_FAIL_REASON_TOO_MANY_ATTEMPTS: PostalVerificationFailReason.ValueType  # 2
"""Too many wrong attempts (5 attempts)"""
Global___PostalVerificationFailReason: typing_extensions.TypeAlias = PostalVerificationFailReason

@typing.final
class HostRequestCreate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_REQUEST_FIELD_NUMBER: builtins.int
    SURFER_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    text: builtins.str
    @property
    def host_request(self) -> requests_pb2.HostRequest: ...
    @property
    def surfer(self) -> api_pb2.User: ...
    def __init__(
        self,
        *,
        host_request: requests_pb2.HostRequest | None = ...,
        surfer: api_pb2.User | None = ...,
        text: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["host_request", b"host_request", "surfer", b"surfer"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["host_request", b"host_request", "surfer", b"surfer", "text", b"text"]) -> None: ...

Global___HostRequestCreate: typing_extensions.TypeAlias = HostRequestCreate

@typing.final
class HostRequestAccept(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_REQUEST_FIELD_NUMBER: builtins.int
    HOST_FIELD_NUMBER: builtins.int
    @property
    def host_request(self) -> requests_pb2.HostRequest: ...
    @property
    def host(self) -> api_pb2.User: ...
    def __init__(
        self,
        *,
        host_request: requests_pb2.HostRequest | None = ...,
        host: api_pb2.User | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["host", b"host", "host_request", b"host_request"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["host", b"host", "host_request", b"host_request"]) -> None: ...

Global___HostRequestAccept: typing_extensions.TypeAlias = HostRequestAccept

@typing.final
class HostRequestReject(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_REQUEST_FIELD_NUMBER: builtins.int
    HOST_FIELD_NUMBER: builtins.int
    @property
    def host_request(self) -> requests_pb2.HostRequest: ...
    @property
    def host(self) -> api_pb2.User: ...
    def __init__(
        self,
        *,
        host_request: requests_pb2.HostRequest | None = ...,
        host: api_pb2.User | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["host", b"host", "host_request", b"host_request"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["host", b"host", "host_request", b"host_request"]) -> None: ...

Global___HostRequestReject: typing_extensions.TypeAlias = HostRequestReject

@typing.final
class HostRequestConfirm(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_REQUEST_FIELD_NUMBER: builtins.int
    SURFER_FIELD_NUMBER: builtins.int
    @property
    def host_request(self) -> requests_pb2.HostRequest: ...
    @property
    def surfer(self) -> api_pb2.User: ...
    def __init__(
        self,
        *,
        host_request: requests_pb2.HostRequest | None = ...,
        surfer: api_pb2.User | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["host_request", b"host_request", "surfer", b"surfer"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["host_request", b"host_request", "surfer", b"surfer"]) -> None: ...

Global___HostRequestConfirm: typing_extensions.TypeAlias = HostRequestConfirm

@typing.final
class HostRequestCancel(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_REQUEST_FIELD_NUMBER: builtins.int
    SURFER_FIELD_NUMBER: builtins.int
    @property
    def host_request(self) -> requests_pb2.HostRequest: ...
    @property
    def surfer(self) -> api_pb2.User: ...
    def __init__(
        self,
        *,
        host_request: requests_pb2.HostRequest | None = ...,
        surfer: api_pb2.User | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["host_request", b"host_request", "surfer", b"surfer"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["host_request", b"host_request", "surfer", b"surfer"]) -> None: ...

Global___HostRequestCancel: typing_extensions.TypeAlias = HostRequestCancel

@typing.final
class HostRequestMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_REQUEST_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    AM_HOST_FIELD_NUMBER: builtins.int
    text: builtins.str
    am_host: builtins.bool
    @property
    def host_request(self) -> requests_pb2.HostRequest: ...
    @property
    def user(self) -> api_pb2.User: ...
    def __init__(
        self,
        *,
        host_request: requests_pb2.HostRequest | None = ...,
        user: api_pb2.User | None = ...,
        text: builtins.str | None = ...,
        am_host: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["host_request", b"host_request", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["am_host", b"am_host", "host_request", b"host_request", "text", b"text", "user", b"user"]) -> None: ...

Global___HostRequestMessage: typing_extensions.TypeAlias = HostRequestMessage

@typing.final
class HostRequestMissedMessages(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_REQUEST_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    AM_HOST_FIELD_NUMBER: builtins.int
    am_host: builtins.bool
    @property
    def host_request(self) -> requests_pb2.HostRequest: ...
    @property
    def user(self) -> api_pb2.User: ...
    def __init__(
        self,
        *,
        host_request: requests_pb2.HostRequest | None = ...,
        user: api_pb2.User | None = ...,
        am_host: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["host_request", b"host_request", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["am_host", b"am_host", "host_request", b"host_request", "user", b"user"]) -> None: ...

Global___HostRequestMissedMessages: typing_extensions.TypeAlias = HostRequestMissedMessages

@typing.final
class HostRequestReminder(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_REQUEST_FIELD_NUMBER: builtins.int
    SURFER_FIELD_NUMBER: builtins.int
    @property
    def host_request(self) -> requests_pb2.HostRequest: ...
    @property
    def surfer(self) -> api_pb2.User: ...
    def __init__(
        self,
        *,
        host_request: requests_pb2.HostRequest | None = ...,
        surfer: api_pb2.User | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["host_request", b"host_request", "surfer", b"surfer"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["host_request", b"host_request", "surfer", b"surfer"]) -> None: ...

Global___HostRequestReminder: typing_extensions.TypeAlias = HostRequestReminder

@typing.final
class BadgeAdd(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BADGE_ID_FIELD_NUMBER: builtins.int
    BADGE_NAME_FIELD_NUMBER: builtins.int
    BADGE_DESCRIPTION_FIELD_NUMBER: builtins.int
    badge_id: builtins.str
    badge_name: builtins.str
    badge_description: builtins.str
    def __init__(
        self,
        *,
        badge_id: builtins.str | None = ...,
        badge_name: builtins.str | None = ...,
        badge_description: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["badge_description", b"badge_description", "badge_id", b"badge_id", "badge_name", b"badge_name"]) -> None: ...

Global___BadgeAdd: typing_extensions.TypeAlias = BadgeAdd

@typing.final
class BadgeRemove(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BADGE_ID_FIELD_NUMBER: builtins.int
    BADGE_NAME_FIELD_NUMBER: builtins.int
    BADGE_DESCRIPTION_FIELD_NUMBER: builtins.int
    badge_id: builtins.str
    badge_name: builtins.str
    badge_description: builtins.str
    def __init__(
        self,
        *,
        badge_id: builtins.str | None = ...,
        badge_name: builtins.str | None = ...,
        badge_description: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["badge_description", b"badge_description", "badge_id", b"badge_id", "badge_name", b"badge_name"]) -> None: ...

Global___BadgeRemove: typing_extensions.TypeAlias = BadgeRemove

@typing.final
class PhoneNumberChange(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PHONE_FIELD_NUMBER: builtins.int
    phone: builtins.str
    def __init__(
        self,
        *,
        phone: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["phone", b"phone"]) -> None: ...

Global___PhoneNumberChange: typing_extensions.TypeAlias = PhoneNumberChange

@typing.final
class PhoneNumberVerify(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PHONE_FIELD_NUMBER: builtins.int
    phone: builtins.str
    def __init__(
        self,
        *,
        phone: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["phone", b"phone"]) -> None: ...

Global___PhoneNumberVerify: typing_extensions.TypeAlias = PhoneNumberVerify

@typing.final
class GenderChange(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GENDER_FIELD_NUMBER: builtins.int
    gender: builtins.str
    def __init__(
        self,
        *,
        gender: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["gender", b"gender"]) -> None: ...

Global___GenderChange: typing_extensions.TypeAlias = GenderChange

@typing.final
class BirthdateChange(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BIRTHDATE_FIELD_NUMBER: builtins.int
    birthdate: builtins.str
    def __init__(
        self,
        *,
        birthdate: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["birthdate", b"birthdate"]) -> None: ...

Global___BirthdateChange: typing_extensions.TypeAlias = BirthdateChange

@typing.final
class FriendRequestCreate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OTHER_USER_FIELD_NUMBER: builtins.int
    @property
    def other_user(self) -> api_pb2.User: ...
    def __init__(
        self,
        *,
        other_user: api_pb2.User | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["other_user", b"other_user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["other_user", b"other_user"]) -> None: ...

Global___FriendRequestCreate: typing_extensions.TypeAlias = FriendRequestCreate

@typing.final
class FriendRequestAccept(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OTHER_USER_FIELD_NUMBER: builtins.int
    @property
    def other_user(self) -> api_pb2.User: ...
    def __init__(
        self,
        *,
        other_user: api_pb2.User | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["other_user", b"other_user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["other_user", b"other_user"]) -> None: ...

Global___FriendRequestAccept: typing_extensions.TypeAlias = FriendRequestAccept

@typing.final
class EmailAddressChange(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NEW_EMAIL_FIELD_NUMBER: builtins.int
    new_email: builtins.str
    def __init__(
        self,
        *,
        new_email: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["new_email", b"new_email"]) -> None: ...

Global___EmailAddressChange: typing_extensions.TypeAlias = EmailAddressChange

@typing.final
class DonationReceived(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AMOUNT_FIELD_NUMBER: builtins.int
    RECEIPT_URL_FIELD_NUMBER: builtins.int
    amount: builtins.int
    """whole dollar amount"""
    receipt_url: builtins.str
    def __init__(
        self,
        *,
        amount: builtins.int | None = ...,
        receipt_url: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["amount", b"amount", "receipt_url", b"receipt_url"]) -> None: ...

Global___DonationReceived: typing_extensions.TypeAlias = DonationReceived

@typing.final
class PasswordResetStart(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PASSWORD_RESET_TOKEN_FIELD_NUMBER: builtins.int
    password_reset_token: builtins.str
    def __init__(
        self,
        *,
        password_reset_token: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["password_reset_token", b"password_reset_token"]) -> None: ...

Global___PasswordResetStart: typing_extensions.TypeAlias = PasswordResetStart

@typing.final
class AccountDeletionStart(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELETION_TOKEN_FIELD_NUMBER: builtins.int
    deletion_token: builtins.str
    def __init__(
        self,
        *,
        deletion_token: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["deletion_token", b"deletion_token"]) -> None: ...

Global___AccountDeletionStart: typing_extensions.TypeAlias = AccountDeletionStart

@typing.final
class AccountDeletionComplete(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UNDELETE_TOKEN_FIELD_NUMBER: builtins.int
    UNDELETE_DAYS_FIELD_NUMBER: builtins.int
    undelete_token: builtins.str
    undelete_days: builtins.int
    def __init__(
        self,
        *,
        undelete_token: builtins.str | None = ...,
        undelete_days: builtins.int | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["undelete_days", b"undelete_days", "undelete_token", b"undelete_token"]) -> None: ...

Global___AccountDeletionComplete: typing_extensions.TypeAlias = AccountDeletionComplete

@typing.final
class ApiKeyCreate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_KEY_FIELD_NUMBER: builtins.int
    EXPIRY_FIELD_NUMBER: builtins.int
    api_key: builtins.str
    @property
    def expiry(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        api_key: builtins.str | None = ...,
        expiry: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["expiry", b"expiry"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["api_key", b"api_key", "expiry", b"expiry"]) -> None: ...

Global___ApiKeyCreate: typing_extensions.TypeAlias = ApiKeyCreate

@typing.final
class EventInviteOrganizer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_FIELD_NUMBER: builtins.int
    INVITING_USER_FIELD_NUMBER: builtins.int
    @property
    def event(self) -> events_pb2.Event: ...
    @property
    def inviting_user(self) -> api_pb2.User: ...
    def __init__(
        self,
        *,
        event: events_pb2.Event | None = ...,
        inviting_user: api_pb2.User | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["event", b"event", "inviting_user", b"inviting_user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["event", b"event", "inviting_user", b"inviting_user"]) -> None: ...

Global___EventInviteOrganizer: typing_extensions.TypeAlias = EventInviteOrganizer

@typing.final
class EventCreate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_FIELD_NUMBER: builtins.int
    INVITING_USER_FIELD_NUMBER: builtins.int
    NEARBY_FIELD_NUMBER: builtins.int
    IN_COMMUNITY_FIELD_NUMBER: builtins.int
    nearby: builtins.bool
    @property
    def event(self) -> events_pb2.Event: ...
    @property
    def inviting_user(self) -> api_pb2.User: ...
    @property
    def in_community(self) -> communities_pb2.Community: ...
    def __init__(
        self,
        *,
        event: events_pb2.Event | None = ...,
        inviting_user: api_pb2.User | None = ...,
        nearby: builtins.bool | None = ...,
        in_community: communities_pb2.Community | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["event", b"event", "in_community", b"in_community", "inviting_user", b"inviting_user", "nearby", b"nearby", "notification_reason", b"notification_reason"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["event", b"event", "in_community", b"in_community", "inviting_user", b"inviting_user", "nearby", b"nearby", "notification_reason", b"notification_reason"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["notification_reason", b"notification_reason"]) -> typing.Literal["nearby", "in_community"] | None: ...

Global___EventCreate: typing_extensions.TypeAlias = EventCreate

@typing.final
class EventUpdate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_FIELD_NUMBER: builtins.int
    UPDATING_USER_FIELD_NUMBER: builtins.int
    UPDATED_ITEMS_FIELD_NUMBER: builtins.int
    @property
    def event(self) -> events_pb2.Event: ...
    @property
    def updating_user(self) -> api_pb2.User: ...
    @property
    def updated_items(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        event: events_pb2.Event | None = ...,
        updating_user: api_pb2.User | None = ...,
        updated_items: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["event", b"event", "updating_user", b"updating_user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["event", b"event", "updated_items", b"updated_items", "updating_user", b"updating_user"]) -> None: ...

Global___EventUpdate: typing_extensions.TypeAlias = EventUpdate

@typing.final
class EventCancel(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_FIELD_NUMBER: builtins.int
    CANCELLING_USER_FIELD_NUMBER: builtins.int
    @property
    def event(self) -> events_pb2.Event: ...
    @property
    def cancelling_user(self) -> api_pb2.User: ...
    def __init__(
        self,
        *,
        event: events_pb2.Event | None = ...,
        cancelling_user: api_pb2.User | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cancelling_user", b"cancelling_user", "event", b"event"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cancelling_user", b"cancelling_user", "event", b"event"]) -> None: ...

Global___EventCancel: typing_extensions.TypeAlias = EventCancel

@typing.final
class EventDelete(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_FIELD_NUMBER: builtins.int
    @property
    def event(self) -> events_pb2.Event: ...
    def __init__(
        self,
        *,
        event: events_pb2.Event | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["event", b"event"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["event", b"event"]) -> None: ...

Global___EventDelete: typing_extensions.TypeAlias = EventDelete

@typing.final
class ChatMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTHOR_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    GROUP_CHAT_ID_FIELD_NUMBER: builtins.int
    message: builtins.str
    text: builtins.str
    group_chat_id: builtins.int
    @property
    def author(self) -> api_pb2.User: ...
    def __init__(
        self,
        *,
        author: api_pb2.User | None = ...,
        message: builtins.str | None = ...,
        text: builtins.str | None = ...,
        group_chat_id: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["author", b"author"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["author", b"author", "group_chat_id", b"group_chat_id", "message", b"message", "text", b"text"]) -> None: ...

Global___ChatMessage: typing_extensions.TypeAlias = ChatMessage

@typing.final
class ChatMissedMessages(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGES_FIELD_NUMBER: builtins.int
    @property
    def messages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___ChatMessage]: ...
    def __init__(
        self,
        *,
        messages: collections.abc.Iterable[Global___ChatMessage] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["messages", b"messages"]) -> None: ...

Global___ChatMissedMessages: typing_extensions.TypeAlias = ChatMissedMessages

@typing.final
class ReferenceReceiveFriend(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FROM_USER_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    text: builtins.str
    @property
    def from_user(self) -> api_pb2.User: ...
    def __init__(
        self,
        *,
        from_user: api_pb2.User | None = ...,
        text: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["from_user", b"from_user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["from_user", b"from_user", "text", b"text"]) -> None: ...

Global___ReferenceReceiveFriend: typing_extensions.TypeAlias = ReferenceReceiveFriend

@typing.final
class ReferenceReceiveHostRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_REQUEST_ID_FIELD_NUMBER: builtins.int
    FROM_USER_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    host_request_id: builtins.int
    text: builtins.str
    """this is non-empty iff both have written a reference, so they are unhidden"""
    @property
    def from_user(self) -> api_pb2.User: ...
    def __init__(
        self,
        *,
        host_request_id: builtins.int | None = ...,
        from_user: api_pb2.User | None = ...,
        text: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["from_user", b"from_user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["from_user", b"from_user", "host_request_id", b"host_request_id", "text", b"text"]) -> None: ...

Global___ReferenceReceiveHostRequest: typing_extensions.TypeAlias = ReferenceReceiveHostRequest

@typing.final
class ReferenceReminder(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_REQUEST_ID_FIELD_NUMBER: builtins.int
    OTHER_USER_FIELD_NUMBER: builtins.int
    DAYS_LEFT_FIELD_NUMBER: builtins.int
    host_request_id: builtins.int
    days_left: builtins.int
    """time left to write the req in days"""
    @property
    def other_user(self) -> api_pb2.User: ...
    def __init__(
        self,
        *,
        host_request_id: builtins.int | None = ...,
        other_user: api_pb2.User | None = ...,
        days_left: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["other_user", b"other_user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["days_left", b"days_left", "host_request_id", b"host_request_id", "other_user", b"other_user"]) -> None: ...

Global___ReferenceReminder: typing_extensions.TypeAlias = ReferenceReminder

@typing.final
class EventReminder(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    @property
    def event(self) -> events_pb2.Event: ...
    @property
    def user(self) -> api_pb2.User: ...
    def __init__(
        self,
        *,
        event: events_pb2.Event | None = ...,
        user: api_pb2.User | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["event", b"event", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["event", b"event", "user", b"user"]) -> None: ...

Global___EventReminder: typing_extensions.TypeAlias = EventReminder

@typing.final
class VerificationSVFail(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REASON_FIELD_NUMBER: builtins.int
    reason: Global___SVFailReason.ValueType
    def __init__(
        self,
        *,
        reason: Global___SVFailReason.ValueType | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["reason", b"reason"]) -> None: ...

Global___VerificationSVFail: typing_extensions.TypeAlias = VerificationSVFail

@typing.final
class PostalVerificationPostcardSent(google.protobuf.message.Message):
    """Postal verification notifications"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CITY_FIELD_NUMBER: builtins.int
    COUNTRY_FIELD_NUMBER: builtins.int
    city: builtins.str
    """Address where postcard was sent (city, country for privacy)"""
    country: builtins.str
    def __init__(
        self,
        *,
        city: builtins.str | None = ...,
        country: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["city", b"city", "country", b"country"]) -> None: ...

Global___PostalVerificationPostcardSent: typing_extensions.TypeAlias = PostalVerificationPostcardSent

@typing.final
class PostalVerificationFailed(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REASON_FIELD_NUMBER: builtins.int
    reason: Global___PostalVerificationFailReason.ValueType
    def __init__(
        self,
        *,
        reason: Global___PostalVerificationFailReason.ValueType | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["reason", b"reason"]) -> None: ...

Global___PostalVerificationFailed: typing_extensions.TypeAlias = PostalVerificationFailed

@typing.final
class EventComment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPLY_FIELD_NUMBER: builtins.int
    EVENT_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    @property
    def reply(self) -> threads_pb2.Reply: ...
    @property
    def event(self) -> events_pb2.Event: ...
    @property
    def author(self) -> api_pb2.User: ...
    def __init__(
        self,
        *,
        reply: threads_pb2.Reply | None = ...,
        event: events_pb2.Event | None = ...,
        author: api_pb2.User | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["author", b"author", "event", b"event", "reply", b"reply"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["author", b"author", "event", b"event", "reply", b"reply"]) -> None: ...

Global___EventComment: typing_extensions.TypeAlias = EventComment

@typing.final
class DiscussionCreate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISCUSSION_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    @property
    def discussion(self) -> discussions_pb2.Discussion: ...
    @property
    def author(self) -> api_pb2.User: ...
    def __init__(
        self,
        *,
        discussion: discussions_pb2.Discussion | None = ...,
        author: api_pb2.User | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["author", b"author", "discussion", b"discussion"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["author", b"author", "discussion", b"discussion"]) -> None: ...

Global___DiscussionCreate: typing_extensions.TypeAlias = DiscussionCreate

@typing.final
class DiscussionComment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPLY_FIELD_NUMBER: builtins.int
    DISCUSSION_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    @property
    def reply(self) -> threads_pb2.Reply: ...
    @property
    def discussion(self) -> discussions_pb2.Discussion: ...
    @property
    def author(self) -> api_pb2.User: ...
    def __init__(
        self,
        *,
        reply: threads_pb2.Reply | None = ...,
        discussion: discussions_pb2.Discussion | None = ...,
        author: api_pb2.User | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["author", b"author", "discussion", b"discussion", "reply", b"reply"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["author", b"author", "discussion", b"discussion", "reply", b"reply"]) -> None: ...

Global___DiscussionComment: typing_extensions.TypeAlias = DiscussionComment

@typing.final
class ThreadReply(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPLY_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    EVENT_FIELD_NUMBER: builtins.int
    DISCUSSION_FIELD_NUMBER: builtins.int
    @property
    def reply(self) -> threads_pb2.Reply: ...
    @property
    def author(self) -> api_pb2.User: ...
    @property
    def event(self) -> events_pb2.Event: ...
    @property
    def discussion(self) -> discussions_pb2.Discussion: ...
    def __init__(
        self,
        *,
        reply: threads_pb2.Reply | None = ...,
        author: api_pb2.User | None = ...,
        event: events_pb2.Event | None = ...,
        discussion: discussions_pb2.Discussion | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["author", b"author", "discussion", b"discussion", "event", b"event", "reply", b"reply", "reply_parent", b"reply_parent"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["author", b"author", "discussion", b"discussion", "event", b"event", "reply", b"reply", "reply_parent", b"reply_parent"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["reply_parent", b"reply_parent"]) -> typing.Literal["event", "discussion"] | None: ...

Global___ThreadReply: typing_extensions.TypeAlias = ThreadReply

@typing.final
class ActivenessProbe(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REMINDER_NUMBER_FIELD_NUMBER: builtins.int
    DEADLINE_FIELD_NUMBER: builtins.int
    reminder_number: builtins.int
    """1, 2, 3, etc"""
    @property
    def deadline(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        reminder_number: builtins.int | None = ...,
        deadline: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["deadline", b"deadline"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["deadline", b"deadline", "reminder_number", b"reminder_number"]) -> None: ...

Global___ActivenessProbe: typing_extensions.TypeAlias = ActivenessProbe

@typing.final
class GeneralNewBlogPost(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    BLURB_FIELD_NUMBER: builtins.int
    url: builtins.str
    title: builtins.str
    blurb: builtins.str
    def __init__(
        self,
        *,
        url: builtins.str | None = ...,
        title: builtins.str | None = ...,
        blurb: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["blurb", b"blurb", "title", b"title", "url", b"url"]) -> None: ...

Global___GeneralNewBlogPost: typing_extensions.TypeAlias = GeneralNewBlogPost



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bugs.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from .google.api import httpbody_pb2 as google_dot_api_dot_httpbody__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nbugs.proto\x12\x11org.couchers.bugs\x1a\x1cgoogle/api/annotations.proto\x1a\x19google/api/httpbody.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x11\x61nnotations.proto\"\x1e\n\x0bVersionInfo\x12\x0f\n\x07version\x18\x01 \x01(\t\"1\n\x10ScreenResolution\x12\r\n\x05width\x18\x01 \x01(\x05\x12\x0e\n\x06height\x18\x02 \x01(\x05\"\xc1\x01\n\x0cReportBugReq\x12\x0f\n\x07subject\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0f\n\x07results\x18\x04 \x01(\t\x12\x18\n\x10\x66rontend_version\x18\x05 \x01(\t\x12\x12\n\nuser_agent\x18\x06 \x01(\t\x12\x0c\n\x04page\x18\x07 \x01(\t\x12>\n\x11screen_resolution\x18\x08 \x01(\x0b\x32#.org.couchers.bugs.ScreenResolution\"/\n\x0cReportBugRes\x12\x0e\n\x06\x62ug_id\x18\x02 \x01(\t\x12\x0f\n\x07\x62ug_url\x18\x03 \x01(\t\"\x1a\n\tStatusReq\x12\r\n\x05nonce\x18\x01 \x01(\t\"B\n\tStatusRes\x12\r\n\x05nonce\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x15\n\rcoucher_count\x18\x03 \x01(\x04\"\x84\x01\n\x18GeolocationSearchInfoReq\x12\x15\n\rsearch_string\x18\x01 \x01(\t\x12\x1d\n\x15nominatim_result_json\x18\x02 \x01(\t\x12\x1d\n\x15\x66ormatted_result_json\x18\x03 \x01(\t\x12\x13\n\x0b\x64uration_ms\x18\x04 \x01(\r\"e\n\x17GeolocationClickInfoReq\x12\x0f\n\x07\x63ontext\x18\x01 \x01(\t\x12\x1d\n\x15\x66ormatted_result_json\x18\x02 \x01(\t\x12\x1a\n\x12search_choice_json\x18\x03 \x01(\t2\xa0\x04\n\x04\x42ugs\x12S\n\x07Version\x12\x16.google.protobuf.Empty\x1a\x1e.org.couchers.bugs.VersionInfo\"\x10\x82\xd3\xe4\x93\x02\n\x12\x08/version\x12O\n\tReportBug\x12\x1f.org.couchers.bugs.ReportBugReq\x1a\x1f.org.couchers.bugs.ReportBugRes\"\x00\x12U\n\x06Status\x12\x1c.org.couchers.bugs.StatusReq\x1a\x1c.org.couchers.bugs.StatusRes\"\x0f\x82\xd3\xe4\x93\x02\t\x12\x07/status\x12W\n\x0eGetDescriptors\x12\x16.google.protobuf.Empty\x1a\x14.google.api.HttpBody\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/descriptors.pb\x12^\n\x15GeolocationSearchInfo\x12+.org.couchers.bugs.GeolocationSearchInfoReq\x1a\x16.google.protobuf.Empty\"\x00\x12\\\n\x14GeolocationClickInfo\x12*.org.couchers.bugs.GeolocationClickInfoReq\x1a\x16.google.protobuf.Empty\"\x00\x1a\x04\x88\xb5\x18\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bugs_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_BUGS']._loaded_options = None
  _globals['_BUGS']._serialized_options = b'\210\265\030\001'
  _globals['_BUGS'].methods_by_name['Version']._loaded_options = None
  _globals['_BUGS'].methods_by_name['Version']._serialized_options = b'\202\323\344\223\002\n\022\010/version'
  _globals['_BUGS'].methods_by_name['Status']._loaded_options = None
  _globals['_BUGS'].methods_by_name['Status']._serialized_options = b'\202\323\344\223\002\t\022\007/status'
  _globals['_BUGS'].methods_by_name['GetDescriptors']._loaded_options = None
  _globals['_BUGS'].methods_by_name['GetDescriptors']._serialized_options = b'\202\323\344\223\002\021\022\017/descriptors.pb'
  _globals['_VERSIONINFO']._serialized_start=138
  _globals['_VERSIONINFO']._serialized_end=168
  _globals['_SCREENRESOLUTION']._serialized_start=170
  _globals['_SCREENRESOLUTION']._serialized_end=219
  _globals['_REPORTBUGREQ']._serialized_start=222
  _globals['_REPORTBUGREQ']._serialized_end=415
  _globals['_REPORTBUGRES']._serialized_start=417
  _globals['_REPORTBUGRES']._serialized_end=464
  _globals['_STATUSREQ']._serialized_start=466
  _globals['_STATUSREQ']._serialized_end=492
  _globals['_STATUSRES']._serialized_start=494
  _globals['_STATUSRES']._serialized_end=560
  _globals['_GEOLOCATIONSEARCHINFOREQ']._serialized_start=563
  _globals['_GEOLOCATIONSEARCHINFOREQ']._serialized_end=695
  _globals['_GEOLOCATIONCLICKINFOREQ']._serialized_start=697
  _globals['_GEOLOCATIONCLICKINFOREQ']._serialized_end=798
  _globals['_BUGS']._serialized_start=801
  _globals['_BUGS']._serialized_end=1345
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import feature_suggestions_pb2 as feature__suggestions__pb2


class FeatureSuggestionsStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListFeatureSuggestions = channel.unary_unary(
                '/org.couchers.api.feature_suggestions.FeatureSuggestions/ListFeatureSuggestions',
                request_serializer=feature__suggestions__pb2.ListFeatureSuggestionsReq.SerializeToString,
                response_deserializer=feature__suggestions__pb2.ListFeatureSuggestionsRes.FromString,
                )
        self.CreateFeatureSuggestion = channel.unary_unary(
                '/org.couchers.api.feature_suggestions.FeatureSuggestions/CreateFeatureSuggestion',
                request_serializer=feature__suggestions__pb2.CreateFeatureSuggestionReq.SerializeToString,
                response_deserializer=feature__suggestions__pb2.FeatureSuggestion.FromString,
                )
        self.VoteOnFeatureSuggestion = channel.unary_unary(
                '/org.couchers.api.feature_suggestions.FeatureSuggestions/VoteOnFeatureSuggestion',
                request_serializer=feature__suggestions__pb2.VoteOnFeatureSuggestionReq.SerializeToString,
                response_deserializer=feature__suggestions__pb2.FeatureSuggestion.FromString,
                )


class FeatureSuggestionsServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListFeatureSuggestions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateFeatureSuggestion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def VoteOnFeatureSuggestion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FeatureSuggestionsServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListFeatureSuggestions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListFeatureSuggestions,
                    request_deserializer=feature__suggestions__pb2.ListFeatureSuggestionsReq.FromString,
                    response_serializer=feature__suggestions__pb2.ListFeatureSuggestionsRes.SerializeToString,
            ),
            'CreateFeatureSuggestion': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateFeatureSuggestion,
                    request_deserializer=feature__suggestions__pb2.CreateFeatureSuggestionReq.FromString,
                    response_serializer=feature__suggestions__pb2.FeatureSuggestion.SerializeToString,
            ),
            'VoteOnFeatureSuggestion': grpc.unary_unary_rpc_method_handler(
                    servicer.VoteOnFeatureSuggestion,
                    request_deserializer=feature__suggestions__pb2.VoteOnFeatureSuggestionReq.FromString,
                    response_serializer=feature__suggestions__pb2.FeatureSuggestion.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'org.couchers.api.feature_suggestions.FeatureSuggestions', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class FeatureSuggestions(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListFeatureSuggestions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.feature_suggestions.FeatureSuggestions/ListFeatureSuggestions',
            feature__suggestions__pb2.ListFeatureSuggestionsReq.SerializeToString,
            feature__suggestions__pb2.ListFeatureSuggestionsRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateFeatureSuggestion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.feature_suggestions.FeatureSuggestions/CreateFeatureSuggestion',
            feature__suggestions__pb2.CreateFeatureSuggestionReq.SerializeToString,
            feature__suggestions__pb2.FeatureSuggestion.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def VoteOnFeatureSuggestion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.feature_suggestions.FeatureSuggestions/VoteOnFeatureSuggestion',
            feature__suggestions__pb2.VoteOnFeatureSuggestionReq.SerializeToString,
            feature__suggestions__pb2.FeatureSuggestion.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: account.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import annotations_pb2 as annotations__pb2
from . import api_pb2 as api__pb2
from . import auth_pb2 as auth__pb2
from . import references_pb2 as references__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\raccount.proto\x12\x18org.couchers.api.account\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x11\x61nnotations.proto\x1a\tapi.proto\x1a\nauth.proto\x1a\x10references.proto\"\xe4\x04\n\x11GetAccountInfoRes\x12\x10\n\x08username\x18\x07 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x18\n\x10profile_complete\x18\x04 \x01(\x08\x12\x18\n\x10my_home_complete\x18\x13 \x01(\x08\x12\r\n\x05phone\x18\x08 \x01(\t\x12\x16\n\x0ephone_verified\x18\t \x01(\x08\x12\x10\n\x08timezone\x18\x06 \x01(\t\x12\x13\n\x0bhas_donated\x18\x0e \x01(\x08\x12\x1f\n\x17has_strong_verification\x18\n \x01(\x08\x12Y\n\x1d\x62irthdate_verification_status\x18\x0b \x01(\x0e\x32\x32.org.couchers.api.core.BirthdateVerificationStatus\x12S\n\x1agender_verification_status\x18\x0c \x01(\x0e\x32/.org.couchers.api.core.GenderVerificationStatus\x12\x14\n\x0c\x64o_not_email\x18\r \x01(\x08\x12\x14\n\x0cis_superuser\x18\x0f \x01(\x08\x12\x1e\n\x16ui_language_preference\x18\x10 \x01(\t\x12T\n\x19profile_public_visibility\x18\x11 \x01(\x0e\x32\x31.org.couchers.api.account.ProfilePublicVisibility\x12\x14\n\x0cis_volunteer\x18\x12 \x01(\x08\x12#\n\x1bshould_show_donation_banner\x18\x14 \x01(\x08\"M\n\x13\x43hangePasswordV2Req\x12\x1a\n\x0cold_password\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\x12\x1a\n\x0cnew_password\x18\x02 \x01(\tB\x04\x80\xb5\x18\x01\"=\n\x10\x43hangeEmailV2Req\x12\x16\n\x08password\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\x12\x11\n\tnew_email\x18\x02 \x01(\t\"=\n\x1b\x43hangeLanguagePreferenceReq\x12\x1e\n\x16ui_language_preference\x18\x01 \x01(\t\"<\n\x19GetContributorFormInfoRes\x12\x1f\n\x17\x66illed_contributor_form\x18\x01 \x01(\x08\"V\n\x16\x46illContributorFormReq\x12<\n\x10\x63ontributor_form\x18\x01 \x01(\x0b\x32\".org.couchers.auth.ContributorForm\"\x1f\n\x0e\x43hangePhoneReq\x12\r\n\x05phone\x18\x01 \x01(\t\"%\n\x0eVerifyPhoneReq\x12\x13\n\x05token\x18\x01 \x01(\tB\x04\x88\xb5\x18\x01\"Y\n\x1dInitiateStrongVerificationRes\x12\"\n\x1averification_attempt_token\x18\x01 \x01(\t\x12\x14\n\x0credirect_url\x18\x03 \x01(\t\"K\n%GetStrongVerificationAttemptStatusReq\x12\"\n\x1averification_attempt_token\x18\x01 \x01(\t\"r\n%GetStrongVerificationAttemptStatusRes\x12I\n\x06status\x18\x01 \x01(\x0e\x32\x39.org.couchers.api.account.StrongVerificationAttemptStatus\"3\n\x10\x44\x65leteAccountReq\x12\x0f\n\x07\x63onfirm\x18\x01 \x01(\x08\x12\x0e\n\x06reason\x18\x02 \x01(\t\"\x8f\x01\n\x07ModNote\x12\x0f\n\x07note_id\x18\x01 \x01(\x04\x12\x14\n\x0cnote_content\x18\x02 \x01(\t\x12+\n\x07\x63reated\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x61\x63knowledged\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"G\n\x0fListModNotesRes\x12\x34\n\tmod_notes\x18\x01 \x03(\x0b\x32!.org.couchers.api.account.ModNote\">\n\x15ListActiveSessionsReq\x12\x11\n\tpage_size\x18\x01 \x01(\r\x12\x12\n\npage_token\x18\x02 \x01(\t\"\x8c\x02\n\rActiveSession\x12+\n\x07\x63reated\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12*\n\x06\x65xpiry\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tlast_seen\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10operating_system\x18\x04 \x01(\t\x12\x0f\n\x07\x62rowser\x18\x05 \x01(\t\x12\x0e\n\x06\x64\x65vice\x18\x06 \x01(\t\x12\x1c\n\x14\x61pproximate_location\x18\x07 \x01(\t\x12\x1a\n\x12is_current_session\x18\x08 \x01(\x08\"r\n\x15ListActiveSessionsRes\x12@\n\x0f\x61\x63tive_sessions\x18\x01 \x03(\x0b\x32\'.org.couchers.api.account.ActiveSession\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"?\n\x10LogOutSessionReq\x12+\n\x07\x63reated\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\")\n\x16LogOutOtherSessionsReq\x12\x0f\n\x07\x63onfirm\x18\x01 \x01(\x08\"u\n\x1dSetProfilePublicVisibilityReq\x12T\n\x19profile_public_visibility\x18\x01 \x01(\x0e\x32\x31.org.couchers.api.account.ProfilePublicVisibility\"\x15\n\x13\x43reateInviteCodeReq\"0\n\x13\x43reateInviteCodeRes\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\"$\n\x14\x44isableInviteCodeReq\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\"\x94\x01\n\x0eInviteCodeInfo\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12+\n\x07\x63reated\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x64isabled\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04uses\x18\x04 \x01(\x05\x12\x0b\n\x03url\x18\x05 \x01(\t\"T\n\x12ListInviteCodesRes\x12>\n\x0cinvite_codes\x18\x01 \x03(\x0b\x32(.org.couchers.api.account.InviteCodeInfo\"\x19\n\x17\x43ompleteProfileReminder\"\x1e\n\x1c\x43ompleteVerificationReminder\"m\n\x1cRespondToHostRequestReminder\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\x12\x34\n\x0bsurfer_user\x18\x02 \x01(\x0b\x32\x1f.org.couchers.api.core.LiteUser\"\xaa\x01\n\x16WriteReferenceReminder\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\x12\x33\n\nother_user\x18\x02 \x01(\x0b\x32\x1f.org.couchers.api.core.LiteUser\x12\x42\n\x0ereference_type\x18\x03 \x01(\x0e\x32*.org.couchers.api.references.ReferenceType\"\x8a\x03\n\x08Reminder\x12V\n\x19\x63omplete_profile_reminder\x18\x01 \x01(\x0b\x32\x31.org.couchers.api.account.CompleteProfileReminderH\x00\x12`\n\x1e\x63omplete_verification_reminder\x18\x02 \x01(\x0b\x32\x36.org.couchers.api.account.CompleteVerificationReminderH\x00\x12\x62\n respond_to_host_request_reminder\x18\x03 \x01(\x0b\x32\x36.org.couchers.api.account.RespondToHostRequestReminderH\x00\x12T\n\x18write_reference_reminder\x18\x04 \x01(\x0b\x32\x30.org.couchers.api.account.WriteReferenceReminderH\x00\x42\n\n\x08reminder\"H\n\x0fGetRemindersRes\x12\x35\n\treminders\x18\x01 \x03(\x0b\x32\".org.couchers.api.account.Reminder\"\xe4\x01\n\x15GetMyVolunteerInfoRes\x12\x14\n\x0c\x64isplay_name\x18\x01 \x01(\t\x12\x18\n\x10\x64isplay_location\x18\x02 \x01(\t\x12\x0c\n\x04role\x18\x03 \x01(\t\x12\x1c\n\x14started_volunteering\x18\x04 \x01(\t\x12\x1c\n\x14stopped_volunteering\x18\x05 \x01(\t\x12\x19\n\x11show_on_team_page\x18\x06 \x01(\x08\x12\x11\n\tlink_type\x18\x07 \x01(\t\x12\x11\n\tlink_text\x18\x08 \x01(\t\x12\x10\n\x08link_url\x18\t \x01(\t\"\xcf\x02\n\x18UpdateMyVolunteerInfoReq\x12\x32\n\x0c\x64isplay_name\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x36\n\x10\x64isplay_location\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x35\n\x11show_on_team_page\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12/\n\tlink_type\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tlink_text\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08link_url\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue*\x94\x03\n\x1fStrongVerificationAttemptStatus\x12.\n*STRONG_VERIFICATION_ATTEMPT_STATUS_UNKNOWN\x10\x00\x12\x30\n,STRONG_VERIFICATION_ATTEMPT_STATUS_SUCCEEDED\x10\x01\x12N\nJSTRONG_VERIFICATION_ATTEMPT_STATUS_IN_PROGRESS_WAITING_ON_USER_TO_OPEN_APP\x10\x02\x12I\nESTRONG_VERIFICATION_ATTEMPT_STATUS_IN_PROGRESS_WAITING_ON_USER_IN_APP\x10\x05\x12\x45\nASTRONG_VERIFICATION_ATTEMPT_STATUS_IN_PROGRESS_WAITING_ON_BACKEND\x10\x03\x12-\n)STRONG_VERIFICATION_ATTEMPT_STATUS_FAILED\x10\x04*\xfe\x01\n\x17ProfilePublicVisibility\x12%\n!PROFILE_PUBLIC_VISIBILITY_UNKNOWN\x10\x00\x12%\n!PROFILE_PUBLIC_VISIBILITY_NOTHING\x10\x01\x12&\n\"PROFILE_PUBLIC_VISIBILITY_MAP_ONLY\x10\x02\x12%\n!PROFILE_PUBLIC_VISIBILITY_LIMITED\x10\x03\x12\"\n\x1ePROFILE_PUBLIC_VISIBILITY_MOST\x10\x04\x12\"\n\x1ePROFILE_PUBLIC_VISIBILITY_FULL\x10\x05\x32\x9e\x12\n\x07\x41\x63\x63ount\x12W\n\x0eGetAccountInfo\x12\x16.google.protobuf.Empty\x1a+.org.couchers.api.account.GetAccountInfoRes\"\x00\x12[\n\x10\x43hangePasswordV2\x12-.org.couchers.api.account.ChangePasswordV2Req\x1a\x16.google.protobuf.Empty\"\x00\x12U\n\rChangeEmailV2\x12*.org.couchers.api.account.ChangeEmailV2Req\x1a\x16.google.protobuf.Empty\"\x00\x12g\n\x16GetContributorFormInfo\x12\x16.google.protobuf.Empty\x1a\x33.org.couchers.api.account.GetContributorFormInfoRes\"\x00\x12\x61\n\x13\x46illContributorForm\x12\x30.org.couchers.api.account.FillContributorFormReq\x1a\x16.google.protobuf.Empty\"\x00\x12k\n\x18\x43hangeLanguagePreference\x12\x35.org.couchers.api.account.ChangeLanguagePreferenceReq\x1a\x16.google.protobuf.Empty\"\x00\x12Q\n\x0b\x43hangePhone\x12(.org.couchers.api.account.ChangePhoneReq\x1a\x16.google.protobuf.Empty\"\x00\x12Q\n\x0bVerifyPhone\x12(.org.couchers.api.account.VerifyPhoneReq\x1a\x16.google.protobuf.Empty\"\x00\x12o\n\x1aInitiateStrongVerification\x12\x16.google.protobuf.Empty\x1a\x37.org.couchers.api.account.InitiateStrongVerificationRes\"\x00\x12\xa8\x01\n\"GetStrongVerificationAttemptStatus\x12?.org.couchers.api.account.GetStrongVerificationAttemptStatusReq\x1a?.org.couchers.api.account.GetStrongVerificationAttemptStatusRes\"\x00\x12P\n\x1c\x44\x65leteStrongVerificationData\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\"\x00\x12U\n\rDeleteAccount\x12*.org.couchers.api.account.DeleteAccountReq\x1a\x16.google.protobuf.Empty\"\x00\x12S\n\x0cListModNotes\x12\x16.google.protobuf.Empty\x1a).org.couchers.api.account.ListModNotesRes\"\x00\x12x\n\x12ListActiveSessions\x12/.org.couchers.api.account.ListActiveSessionsReq\x1a/.org.couchers.api.account.ListActiveSessionsRes\"\x00\x12U\n\rLogOutSession\x12*.org.couchers.api.account.LogOutSessionReq\x1a\x16.google.protobuf.Empty\"\x00\x12\x61\n\x13LogOutOtherSessions\x12\x30.org.couchers.api.account.LogOutOtherSessionsReq\x1a\x16.google.protobuf.Empty\"\x00\x12o\n\x1aSetProfilePublicVisibility\x12\x37.org.couchers.api.account.SetProfilePublicVisibilityReq\x1a\x16.google.protobuf.Empty\"\x00\x12r\n\x10\x43reateInviteCode\x12-.org.couchers.api.account.CreateInviteCodeReq\x1a-.org.couchers.api.account.CreateInviteCodeRes\"\x00\x12]\n\x11\x44isableInviteCode\x12..org.couchers.api.account.DisableInviteCodeReq\x1a\x16.google.protobuf.Empty\"\x00\x12Y\n\x0fListInviteCodes\x12\x16.google.protobuf.Empty\x1a,.org.couchers.api.account.ListInviteCodesRes\"\x00\x12S\n\x0cGetReminders\x12\x16.google.protobuf.Empty\x1a).org.couchers.api.account.GetRemindersRes\"\x00\x12_\n\x12GetMyVolunteerInfo\x12\x16.google.protobuf.Empty\x1a/.org.couchers.api.account.GetMyVolunteerInfoRes\"\x00\x12~\n\x15UpdateMyVolunteerInfo\x12\x32.org.couchers.api.account.UpdateMyVolunteerInfoReq\x1a/.org.couchers.api.account.GetMyVolunteerInfoRes\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'account_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CHANGEPASSWORDV2REQ'].fields_by_name['old_password']._loaded_options = None
  _globals['_CHANGEPASSWORDV2REQ'].fields_by_name['old_password']._serialized_options = b'\200\265\030\001'
  _globals['_CHANGEPASSWORDV2REQ'].fields_by_name['new_password']._loaded_options = None
  _globals['_CHANGEPASSWORDV2REQ'].fields_by_name['new_password']._serialized_options = b'\200\265\030\001'
  _globals['_CHANGEEMAILV2REQ'].fields_by_name['password']._loaded_options = None
  _globals['_CHANGEEMAILV2REQ'].fields_by_name['password']._serialized_options = b'\200\265\030\001'
  _globals['_VERIFYPHONEREQ'].fields_by_name['token']._loaded_options = None
  _globals['_VERIFYPHONEREQ'].fields_by_name['token']._serialized_options = b'\210\265\030\001'
  _globals['_ACCOUNT']._loaded_options = None
  _globals['_ACCOUNT']._serialized_options = b'\210\265\030\003'
  _globals['_STRONGVERIFICATIONATTEMPTSTATUS']._serialized_start=4205
  _globals['_STRONGVERIFICATIONATTEMPTSTATUS']._serialized_end=4609
  _globals['_PROFILEPUBLICVISIBILITY']._serialized_start=4612
  _globals['_PROFILEPUBLICVISIBILITY']._serialized_end=4866
  _globals['_GETACCOUNTINFORES']._serialized_start=198
  _globals['_GETACCOUNTINFORES']._serialized_end=810
  _globals['_CHANGEPASSWORDV2REQ']._serialized_start=812
  _globals['_CHANGEPASSWORDV2REQ']._serialized_end=889
  _globals['_CHANGEEMAILV2REQ']._serialized_start=891
  _globals['_CHANGEEMAILV2REQ']._serialized_end=952
  _globals['_CHANGELANGUAGEPREFERENCEREQ']._serialized_start=954
  _globals['_CHANGELANGUAGEPREFERENCEREQ']._serialized_end=1015
  _globals['_GETCONTRIBUTORFORMINFORES']._serialized_start=1017
  _globals['_GETCONTRIBUTORFORMINFORES']._serialized_end=1077
  _globals['_FILLCONTRIBUTORFORMREQ']._serialized_start=1079
  _globals['_FILLCONTRIBUTORFORMREQ']._serialized_end=1165
  _globals['_CHANGEPHONEREQ']._serialized_start=1167
  _globals['_CHANGEPHONEREQ']._serialized_end=1198
  _globals['_VERIFYPHONEREQ']._serialized_start=1200
  _globals['_VERIFYPHONEREQ']._serialized_end=1237
  _globals['_INITIATESTRONGVERIFICATIONRES']._serialized_start=1239
  _globals['_INITIATESTRONGVERIFICATIONRES']._serialized_end=1328
  _globals['_GETSTRONGVERIFICATIONATTEMPTSTATUSREQ']._serialized_start=1330
  _globals['_GETSTRONGVERIFICATIONATTEMPTSTATUSREQ']._serialized_end=1405
  _globals['_GETSTRONGVERIFICATIONATTEMPTSTATUSRES']._serialized_start=1407
  _globals['_GETSTRONGVERIFICATIONATTEMPTSTATUSRES']._serialized_end=1521
  _globals['_DELETEACCOUNTREQ']._serialized_start=1523
  _globals['_DELETEACCOUNTREQ']._serialized_end=1574
  _globals['_MODNOTE']._serialized_start=1577
  _globals['_MODNOTE']._serialized_end=1720
  _globals['_LISTMODNOTESRES']._serialized_start=1722
  _globals['_LISTMODNOTESRES']._serialized_end=1793
  _globals['_LISTACTIVESESSIONSREQ']._serialized_start=1795
  _globals['_LISTACTIVESESSIONSREQ']._serialized_end=1857
  _globals['_ACTIVESESSION']._serialized_start=1860
  _globals['_ACTIVESESSION']._serialized_end=2128
  _globals['_LISTACTIVESESSIONSRES']._serialized_start=2130
  _globals['_LISTACTIVESESSIONSRES']._serialized_end=2244
  _globals['_LOGOUTSESSIONREQ']._serialized_start=2246
  _globals['_LOGOUTSESSIONREQ']._serialized_end=2309
  _globals['_LOGOUTOTHERSESSIONSREQ']._serialized_start=2311
  _globals['_LOGOUTOTHERSESSIONSREQ']._serialized_end=2352
  _globals['_SETPROFILEPUBLICVISIBILITYREQ']._serialized_start=2354
  _globals['_SETPROFILEPUBLICVISIBILITYREQ']._serialized_end=2471
  _globals['_CREATEINVITECODEREQ']._serialized_start=2473
  _globals['_CREATEINVITECODEREQ']._serialized_end=2494
  _globals['_CREATEINVITECODERES']._serialized_start=2496
  _globals['_CREATEINVITECODERES']._serialized_end=2544
  _globals['_DISABLEINVITECODEREQ']._serialized_start=2546
  _globals['_DISABLEINVITECODEREQ']._serialized_end=2582
  _globals['_INVITECODEINFO']._serialized_start=2585
  _globals['_INVITECODEINFO']._serialized_end=2733
  _globals['_LISTINVITECODESRES']._serialized_start=2735
  _globals['_LISTINVITECODESRES']._serialized_end=2819
  _globals['_COMPLETEPROFILEREMINDER']._serialized_start=2821
  _globals['_COMPLETEPROFILEREMINDER']._serialized_end=2846
  _globals['_COMPLETEVERIFICATIONREMINDER']._serialized_start=2848
  _globals['_COMPLETEVERIFICATIONREMINDER']._serialized_end=2878
  _globals['_RESPONDTOHOSTREQUESTREMINDER']._serialized_start=2880
  _globals['_RESPONDTOHOSTREQUESTREMINDER']._serialized_end=2989
  _globals['_WRITEREFERENCEREMINDER']._serialized_start=2992
  _globals['_WRITEREFERENCEREMINDER']._serialized_end=3162
  _globals['_REMINDER']._serialized_start=3165
  _globals['_REMINDER']._serialized_end=3559
  _globals['_GETREMINDERSRES']._serialized_start=3561
  _globals['_GETREMINDERSRES']._serialized_end=3633
  _globals['_GETMYVOLUNTEERINFORES']._serialized_start=3636
  _globals['_GETMYVOLUNTEERINFORES']._serialized_end=3864
  _globals['_UPDATEMYVOLUNTEERINFOREQ']._serialized_start=3867
  _globals['_UPDATEMYVOLUNTEERINFOREQ']._serialized_end=4202
  _globals['_ACCOUNT']._serialized_start=4869
  _globals['_ACCOUNT']._serialized_end=7203
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: moderation.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10moderation.proto\x12\x17org.couchers.moderation\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x11\x61nnotations.proto\"\xa6\x02\n\x13ModerationStateInfo\x12\x1b\n\x13moderation_state_id\x18\x01 \x01(\x03\x12\x42\n\x0bobject_type\x18\x02 \x01(\x0e\x32-.org.couchers.moderation.ModerationObjectType\x12\x11\n\tobject_id\x18\x03 \x01(\x03\x12\x41\n\nvisibility\x18\x04 \x01(\x0e\x32-.org.couchers.moderation.ModerationVisibility\x12+\n\x07\x63reated\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07updated\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xe2\x02\n\x17ModerationQueueItemInfo\x12\x15\n\rqueue_item_id\x18\x01 \x01(\x03\x12\x1b\n\x13moderation_state_id\x18\x02 \x01(\x03\x12\x30\n\x0ctime_created\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12;\n\x07trigger\x18\x04 \x01(\x0e\x32*.org.couchers.moderation.ModerationTrigger\x12\x0e\n\x06reason\x18\x05 \x01(\t\x12\x1b\n\x13item_author_user_id\x18\x06 \x01(\x03\x12\x13\n\x0bis_resolved\x18\x07 \x01(\x08\x12\x1a\n\x12resolved_by_log_id\x18\x08 \x01(\x03\x12\x46\n\x10moderation_state\x18\t \x01(\x0b\x32,.org.couchers.moderation.ModerationStateInfo\"\xa2\x02\n\x16ModerationLogEntryInfo\x12\x14\n\x0clog_entry_id\x18\x01 \x01(\x03\x12\x1b\n\x13moderation_state_id\x18\x02 \x01(\x03\x12(\n\x04time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x06\x61\x63tion\x18\x04 \x01(\x0e\x32).org.couchers.moderation.ModerationAction\x12\x19\n\x11moderator_user_id\x18\x05 \x01(\x03\x12\x45\n\x0enew_visibility\x18\x06 \x01(\x0e\x32-.org.couchers.moderation.ModerationVisibility\x12\x0e\n\x06reason\x18\x07 \x01(\t\"\xf3\x02\n\x15GetModerationQueueReq\x12<\n\x08triggers\x18\x04 \x03(\x0e\x32*.org.couchers.moderation.ModerationTrigger\x12\x42\n\x0bobject_type\x18\x05 \x01(\x0e\x32-.org.couchers.moderation.ModerationObjectType\x12\x17\n\x0funresolved_only\x18\x06 \x01(\x08\x12\x32\n\x0e\x63reated_before\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rcreated_after\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1b\n\x13item_author_user_id\x18\t \x01(\x03\x12\x11\n\tpage_size\x18\x01 \x01(\r\x12\x12\n\npage_token\x18\x02 \x01(\t\x12\x14\n\x0cnewest_first\x18\x03 \x01(\x08\"w\n\x15GetModerationQueueRes\x12\x45\n\x0bqueue_items\x18\x01 \x03(\x0b\x32\x30.org.couchers.moderation.ModerationQueueItemInfo\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"n\n\x15GetModerationStateReq\x12\x42\n\x0bobject_type\x18\x01 \x01(\x0e\x32-.org.couchers.moderation.ModerationObjectType\x12\x11\n\tobject_id\x18\x02 \x01(\x03\"_\n\x15GetModerationStateRes\x12\x46\n\x10moderation_state\x18\x01 \x01(\x0b\x32,.org.couchers.moderation.ModerationStateInfo\"2\n\x13GetModerationLogReq\x12\x1b\n\x13moderation_state_id\x18\x01 \x01(\x03\"\xa3\x01\n\x13GetModerationLogRes\x12\x44\n\x0blog_entries\x18\x01 \x03(\x0b\x32/.org.couchers.moderation.ModerationLogEntryInfo\x12\x46\n\x10moderation_state\x18\x02 \x01(\x0b\x32,.org.couchers.moderation.ModerationStateInfo\"\xbf\x01\n\x12ModerateContentReq\x12\x1b\n\x13moderation_state_id\x18\x01 \x01(\x03\x12\x39\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32).org.couchers.moderation.ModerationAction\x12\x41\n\nvisibility\x18\x03 \x01(\x0e\x32-.org.couchers.moderation.ModerationVisibility\x12\x0e\n\x06reason\x18\x04 \x01(\t\"\\\n\x12ModerateContentRes\x12\x46\n\x10moderation_state\x18\x01 \x01(\x0b\x32,.org.couchers.moderation.ModerationStateInfo\"\x83\x01\n\x17\x46lagContentForReviewReq\x12\x1b\n\x13moderation_state_id\x18\x01 \x01(\x03\x12;\n\x07trigger\x18\x02 \x01(\x0e\x32*.org.couchers.moderation.ModerationTrigger\x12\x0e\n\x06reason\x18\x03 \x01(\t\"_\n\x17\x46lagContentForReviewRes\x12\x44\n\nqueue_item\x18\x01 \x01(\x0b\x32\x30.org.couchers.moderation.ModerationQueueItemInfo\"?\n\x10UnflagContentReq\x12\x1b\n\x13moderation_state_id\x18\x01 \x01(\x03\x12\x0e\n\x06reason\x18\x02 \x01(\t\"Z\n\x10UnflagContentRes\x12\x46\n\x10moderation_state\x18\x01 \x01(\x0b\x32,.org.couchers.moderation.ModerationStateInfo*\xca\x01\n\x14ModerationVisibility\x12%\n!MODERATION_VISIBILITY_UNSPECIFIED\x10\x00\x12 \n\x1cMODERATION_VISIBILITY_HIDDEN\x10\x01\x12\"\n\x1eMODERATION_VISIBILITY_SHADOWED\x10\x02\x12!\n\x1dMODERATION_VISIBILITY_VISIBLE\x10\x03\x12\"\n\x1eMODERATION_VISIBILITY_UNLISTED\x10\x04*\xce\x01\n\x11ModerationTrigger\x12\"\n\x1eMODERATION_TRIGGER_UNSPECIFIED\x10\x00\x12%\n!MODERATION_TRIGGER_INITIAL_REVIEW\x10\x01\x12 \n\x1cMODERATION_TRIGGER_USER_FLAG\x10\x02\x12#\n\x1fMODERATION_TRIGGER_MACHINE_FLAG\x10\x03\x12\'\n#MODERATION_TRIGGER_MODERATOR_REVIEW\x10\x04*\xc8\x01\n\x10ModerationAction\x12!\n\x1dMODERATION_ACTION_UNSPECIFIED\x10\x00\x12\x1c\n\x18MODERATION_ACTION_CREATE\x10\x01\x12\x1d\n\x19MODERATION_ACTION_APPROVE\x10\x02\x12\x1a\n\x16MODERATION_ACTION_HIDE\x10\x03\x12\x1a\n\x16MODERATION_ACTION_FLAG\x10\x04\x12\x1c\n\x18MODERATION_ACTION_UNFLAG\x10\x05*\x8e\x01\n\x14ModerationObjectType\x12&\n\"MODERATION_OBJECT_TYPE_UNSPECIFIED\x10\x00\x12\'\n#MODERATION_OBJECT_TYPE_HOST_REQUEST\x10\x01\x12%\n!MODERATION_OBJECT_TYPE_GROUP_CHAT\x10\x02\x32\xca\x05\n\nModeration\x12v\n\x12GetModerationQueue\x12..org.couchers.moderation.GetModerationQueueReq\x1a..org.couchers.moderation.GetModerationQueueRes\"\x00\x12v\n\x12GetModerationState\x12..org.couchers.moderation.GetModerationStateReq\x1a..org.couchers.moderation.GetModerationStateRes\"\x00\x12p\n\x10GetModerationLog\x12,.org.couchers.moderation.GetModerationLogReq\x1a,.org.couchers.moderation.GetModerationLogRes\"\x00\x12m\n\x0fModerateContent\x12+.org.couchers.moderation.ModerateContentReq\x1a+.org.couchers.moderation.ModerateContentRes\"\x00\x12|\n\x14\x46lagContentForReview\x12\x30.org.couchers.moderation.FlagContentForReviewReq\x1a\x30.org.couchers.moderation.FlagContentForReviewRes\"\x00\x12g\n\rUnflagContent\x12).org.couchers.moderation.UnflagContentReq\x1a).org.couchers.moderation.UnflagContentRes\"\x00\x1a\x04\x88\xb5\x18\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'moderation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_MODERATION']._loaded_options = None
  _globals['_MODERATION']._serialized_options = b'\210\265\030\004'
  _globals['_MODERATIONVISIBILITY']._serialized_start=2643
  _globals['_MODERATIONVISIBILITY']._serialized_end=2845
  _globals['_MODERATIONTRIGGER']._serialized_start=2848
  _globals['_MODERATIONTRIGGER']._serialized_end=3054
  _globals['_MODERATIONACTION']._serialized_start=3057
  _globals['_MODERATIONACTION']._serialized_end=3257
  _globals['_MODERATIONOBJECTTYPE']._serialized_start=3260
  _globals['_MODERATIONOBJECTTYPE']._serialized_end=3402
  _globals['_MODERATIONSTATEINFO']._serialized_start=98
  _globals['_MODERATIONSTATEINFO']._serialized_end=392
  _globals['_MODERATIONQUEUEITEMINFO']._serialized_start=395
  _globals['_MODERATIONQUEUEITEMINFO']._serialized_end=749
  _globals['_MODERATIONLOGENTRYINFO']._serialized_start=752
  _globals['_MODERATIONLOGENTRYINFO']._serialized_end=1042
  _globals['_GETMODERATIONQUEUEREQ']._serialized_start=1045
  _globals['_GETMODERATIONQUEUEREQ']._serialized_end=1416
  _globals['_GETMODERATIONQUEUERES']._serialized_start=1418
  _globals['_GETMODERATIONQUEUERES']._serialized_end=1537
  _globals['_GETMODERATIONSTATEREQ']._serialized_start=1539
  _globals['_GETMODERATIONSTATEREQ']._serialized_end=1649
  _globals['_GETMODERATIONSTATERES']._serialized_start=1651
  _globals['_GETMODERATIONSTATERES']._serialized_end=1746
  _globals['_GETMODERATIONLOGREQ']._serialized_start=1748
  _globals['_GETMODERATIONLOGREQ']._serialized_end=1798
  _globals['_GETMODERATIONLOGRES']._serialized_start=1801
  _globals['_GETMODERATIONLOGRES']._serialized_end=1964
  _globals['_MODERATECONTENTREQ']._serialized_start=1967
  _globals['_MODERATECONTENTREQ']._serialized_end=2158
  _globals['_MODERATECONTENTRES']._serialized_start=2160
  _globals['_MODERATECONTENTRES']._serialized_end=2252
  _globals['_FLAGCONTENTFORREVIEWREQ']._serialized_start=2255
  _globals['_FLAGCONTENTFORREVIEWREQ']._serialized_end=2386
  _globals['_FLAGCONTENTFORREVIEWRES']._serialized_start=2388
  _globals['_FLAGCONTENTFORREVIEWRES']._serialized_end=2483
  _globals['_UNFLAGCONTENTREQ']._serialized_start=2485
  _globals['_UNFLAGCONTENTREQ']._serialized_end=2548
  _globals['_UNFLAGCONTENTRES']._serialized_start=2550
  _globals['_UNFLAGCONTENTRES']._serialized_end=2640
  _globals['_MODERATION']._serialized_start=3405
  _globals['_MODERATION']._serialized_end=4119
# @@protoc_insertion_point(module_scope)
